==> haskell-aeson-yaml-1.1.0.1-187-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-LcTOAmvvT4pDNaA0mLwIWX
key:                  aeson-yaml-1.1.0.1-LcTOAmvvT4pDNaA0mLwIWX
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  87db2863194f72cb85260b9e3def0959
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-LcTOAmvvT4pDNaA0mLwIWX
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-yaml-1.1.0.1-200-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-F52H2ZYs7oRLgOgcvasHVR
key:                  aeson-yaml-1.1.0.1-F52H2ZYs7oRLgOgcvasHVR
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  d1233887dd7c22a67ca9119f9a8cb288
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-F52H2ZYs7oRLgOgcvasHVR
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
